@@ -46,10 +46,10 @@ class Scenario:
     self.cli._send(Scenario._encode_json(j))
 
   def _decide(self, j):
+    if self.nis:
+      self._terminate_scenario(j)
     if self.init:
       self._continue_scenario(j)
-    elif self.nis:
-      self._terminate_scenario(j)
     else:
       self._init_scenario(j)
 
@@ -83,7 +83,7 @@ class Scenario:
     j = {"store_in_memory": values_dict}
     self._decide(j)
 
-  def read_cells(self, keys_arr, buffer_size=0):
+  def read_cells(self, keys_arr, buffer_size=8192):
     if not self.init or self.nis:
       return None
     j = {"memory_cells": keys_arr}
@@ -93,7 +93,7 @@ class Scenario:
     else:
       return j["memory_values"]
 
-  def listen(self, buffer_size=0):
+  def listen(self, buffer_size=8192):
     if not self.init or self.nis:
       raise ScenarioNotStartedException
     try:
@@ -106,7 +106,7 @@ class Scenario:
         raise ScenarioTerminatedException
     return j
 
-  def wait(self, buffer_size=0):
+  def wait(self, buffer_size=8192):
     while True:
       msg = self.listen(buffer_size)
       if len(msg) == 0:
